Biskit — biskit 3.0.0a1 documentation

# Biskit

## Main Classes

The most important classes which can be directly imported from the Biskit namespace.

`PDBModel` | Store and manipulate coordinates and atom infos stemming from a PDB file.
`ProfileCollection` | Manage profiles (arrays or lists of values) for Trajectory frames or atoms/residues in PDBModel.
`PDBCleaner` | PDBCleaner performs the following tasks:
`Trajectory` |
`EnsembleTraj` |
`Residue` |
`AmberResidueType` | Standard description of a certain class of residues.
`AmberPrepParser` | Parse Amber Residue libraries (off or prep files) which are usually found in amber/dat/leap/prep.
`LogFile` | Simple log file that can be passed between objects.
`StdLog` | Print to std out.
`ErrLog` | Print to stderr instead.

## Interaction with external programs

`Executor` |
`ExeConfig` |
`ExeConfigCache` |
`AmberCrdEntropist` |
`AmberCrdParser` |
`AmberLeap` |
`AmberParmBuilder` |
`AmberRstParser` |
`AmberResidueLibrary` | A collection of reference residue types taken from Amber topology files.
`TMAlign` |

## Supporting classes and modules

`BioUnit` |
`LocalPath` | Encapsulate a file name that might look differently in different environments depending on environment settings.
`SettingsManager` |
`SettingsParser` |

## Helper Modules

Modules with utility and helper methods.

`gnuplot` | Simple Gnuplot interface.
`hist` | create a histogram from data
`tools` | general purpose utility methods.
`molUtils` | Utilities for handling structures and sequences
`mathUtils` | general purpose math methods
`match2seq` | Match 2 sequences against each other, deleting all positions that differ.
`rmsFit` | superimpose 2 structures iteratively

## Errors

Errors that are raised by biskit classes.

`EHandler` | Default Error Handler for Biskit classes.
`BiskitError` | Root for all Errors raised by Biskit scripts.
`LocalPathError` |
`PDBError` |
`ProfileError` |